# crc-pulp_service-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 20260224.2
- Generator version: 7.10.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pulpcore.client.pulp_service
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pulpcore.client.pulp_service
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import pulpcore.client.pulp_service
from pulpcore.client.pulp_service.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://env-ephemeral-rjacr3.apps.crc-eph.r9lp.p1.openshiftapps.com
# See configuration.py for a list of all supported configuration parameters.
configuration = pulpcore.client.pulp_service.Configuration(
    host = "https://env-ephemeral-rjacr3.apps.crc-eph.r9lp.p1.openshiftapps.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = pulpcore.client.pulp_service.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)

# Configure API key authorization: cookieAuth
configuration.api_key['cookieAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['cookieAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with pulpcore.client.pulp_service.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pulpcore.client.pulp_service.ApiCreateDomainApi(api_client)
    domain = pulpcore.client.pulp_service.Domain() # Domain | 
    x_task_diagnostics = ['x_task_diagnostics_example'] # List[str] | List of profilers to use on tasks. (optional)

    try:
        # Create domain
        api_response = api_instance.post(domain, x_task_diagnostics=x_task_diagnostics)
        print("The response of ApiCreateDomainApi->post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApiCreateDomainApi->post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://env-ephemeral-rjacr3.apps.crc-eph.r9lp.p1.openshiftapps.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiCreateDomainApi* | [**post**](docs/ApiCreateDomainApi.md#post) | **POST** /api/pulp/create-domain/ | Create domain
*ApiDebugAuthHeaderApi* | [**get**](docs/ApiDebugAuthHeaderApi.md#get) | **GET** /api/pulp/debug_auth_header/ | 
*ApiDebugDatabaseTriggersApi* | [**get**](docs/ApiDebugDatabaseTriggersApi.md#get) | **GET** /api/pulp/debug/database-triggers/ | 
*ApiDebugReleaseTaskLocksApi* | [**get**](docs/ApiDebugReleaseTaskLocksApi.md#get) | **GET** /api/pulp/debug/release-task-locks/ | 
*ApiRdsConnectionTestsApi* | [**get**](docs/ApiRdsConnectionTestsApi.md#get) | **GET** /api/pulp/rds-connection-tests/ | 
*ApiRdsConnectionTestsApi* | [**post**](docs/ApiRdsConnectionTestsApi.md#post) | **POST** /api/pulp/rds-connection-tests/ | Dispatch RDS connection tests
*ApiTestRandomLockTasksApi* | [**get**](docs/ApiTestRandomLockTasksApi.md#get) | **GET** /api/pulp/test/random_lock_tasks/ | 
*ApiTestTasksApi* | [**get**](docs/ApiTestTasksApi.md#get) | **GET** /api/pulp/test/tasks/ | 
*ContentguardsFeatureApi* | [**add_role**](docs/ContentguardsFeatureApi.md#add_role) | **POST** {service_feature_content_guard_href}add_role/ | Add a role
*ContentguardsFeatureApi* | [**create**](docs/ContentguardsFeatureApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/contentguards/service/feature/ | Create a feature content guard
*ContentguardsFeatureApi* | [**delete**](docs/ContentguardsFeatureApi.md#delete) | **DELETE** {service_feature_content_guard_href} | Delete a feature content guard
*ContentguardsFeatureApi* | [**list**](docs/ContentguardsFeatureApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/contentguards/service/feature/ | List feature content guards
*ContentguardsFeatureApi* | [**list_roles**](docs/ContentguardsFeatureApi.md#list_roles) | **GET** {service_feature_content_guard_href}list_roles/ | List roles
*ContentguardsFeatureApi* | [**my_permissions**](docs/ContentguardsFeatureApi.md#my_permissions) | **GET** {service_feature_content_guard_href}my_permissions/ | List user permissions
*ContentguardsFeatureApi* | [**partial_update**](docs/ContentguardsFeatureApi.md#partial_update) | **PATCH** {service_feature_content_guard_href} | Update a feature content guard
*ContentguardsFeatureApi* | [**read**](docs/ContentguardsFeatureApi.md#read) | **GET** {service_feature_content_guard_href} | Inspect a feature content guard
*ContentguardsFeatureApi* | [**remove_role**](docs/ContentguardsFeatureApi.md#remove_role) | **POST** {service_feature_content_guard_href}remove_role/ | Remove a role
*ContentguardsFeatureApi* | [**update**](docs/ContentguardsFeatureApi.md#update) | **PUT** {service_feature_content_guard_href} | Update a feature content guard
*TasksApi* | [**admin_tasks**](docs/TasksApi.md#admin_tasks) | **GET** /api/pulp/admin/tasks/ | 
*VulnReportServiceApi* | [**create**](docs/VulnReportServiceApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/vuln_report_service/ | Generate vulnerability report
*VulnReportServiceApi* | [**delete**](docs/VulnReportServiceApi.md#delete) | **DELETE** {service_vulnerability_report_href} | Delete a vulnerability report
*VulnReportServiceApi* | [**list**](docs/VulnReportServiceApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/vuln_report_service/ | List vulnerability reports
*VulnReportServiceApi* | [**read**](docs/VulnReportServiceApi.md#read) | **GET** {service_vulnerability_report_href} | Inspect a vulnerability report


## Documentation For Models

 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [Domain](docs/Domain.md)
 - [DomainResponse](docs/DomainResponse.md)
 - [MyPermissionsResponse](docs/MyPermissionsResponse.md)
 - [NestedRole](docs/NestedRole.md)
 - [NestedRoleResponse](docs/NestedRoleResponse.md)
 - [ObjectRolesResponse](docs/ObjectRolesResponse.md)
 - [PaginatedTaskResponseList](docs/PaginatedTaskResponseList.md)
 - [PaginatedserviceFeatureContentGuardResponseList](docs/PaginatedserviceFeatureContentGuardResponseList.md)
 - [PaginatedserviceVulnerabilityReportResponseList](docs/PaginatedserviceVulnerabilityReportResponseList.md)
 - [PatchedserviceFeatureContentGuard](docs/PatchedserviceFeatureContentGuard.md)
 - [ProgressReportResponse](docs/ProgressReportResponse.md)
 - [ServiceFeatureContentGuard](docs/ServiceFeatureContentGuard.md)
 - [ServiceFeatureContentGuardResponse](docs/ServiceFeatureContentGuardResponse.md)
 - [ServiceVulnerabilityReportResponse](docs/ServiceVulnerabilityReportResponse.md)
 - [StorageClassEnum](docs/StorageClassEnum.md)
 - [TaskResponse](docs/TaskResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="cookieAuth"></a>
### cookieAuth

- **Type**: API key
- **API key parameter name**: sessionid
- **Location**: 


## Author

pulp-list@redhat.com


